@@ -1,12 +1,15 @@
 <?php
 /**
- * $Horde: chora/patchsets.php,v 1.18.8.6 2007/02/23 03:58:53 selsky Exp $
+ * $Horde: chora/patchsets.php,v 1.18.8.8 2009/01/06 15:22:34 jan Exp $
  *
- * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 1999-2007 Charles Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author  Anil Madhavapeddy <anil@recoil.org>
+ * @author  Chuck Hagenbuch <chuck@horde.org>
+ * @package Chora
  */
 
 @define('CHORA_BASE', dirname(__FILE__));
@@ -19,28 +22,31 @@ if (empty($conf['paths']['cvsps']) && !is_a($VC, 'VC_svn')) {
 }
 
 if (@is_dir($fullname)) {
-    Chora::fatal('No patchsets for directories yet.');
+    Chora::fatal('403 Forbidden', 'No patchsets for directories yet.');
 }
 
 if (!$VC->isFile($fullname)) {
-    Chora::fatal("$where: no such file or directory");
+    Chora::fatal('404 Not Found', "$where: no such file or directory");
 }
 
 $ps = $VC->getPatchsetObject($where, $cache);
 Chora::checkError($ps);
 
-$title = sprintf(_("Patchsets for %s"), Text::htmlallspaces($where));
-$upwhere = preg_replace('|[^/]+$|', '', $where);
+$title = sprintf(_("Patchsets for %s"), $where);
 $extraLink = Chora::getFileViews();
 
+Horde::addScriptFile('prototype.js', 'chora', true);
+Horde::addScriptFile('tables.js', 'chora', true);
+Horde::addScriptFile('QuickFinder.js', 'chora', true);
 require CHORA_TEMPLATES . '/common-header.inc';
 require CHORA_TEMPLATES . '/menu.inc';
 require CHORA_TEMPLATES . '/headerbar.inc';
+require CHORA_TEMPLATES . '/patchsets/header.inc';
 
 $patchsets = $ps->_patchsets;
 krsort($patchsets);
 foreach ($patchsets as $id => $patchset) {
-    $commitDate = @strftime('%c', $patchset['date']);
+    $commitDate = Chora::formatTime($patchset['date']);
     $readableDate = Chora::readableTime($patchset['date'], true);
     $author = Chora::showAuthorName($patchset['author'], true);
     if (is_a($VC, 'VC_svn')) {
@@ -49,11 +55,11 @@ foreach ($patchsets as $id => $patchset) {
         $topDir = substr($where, 0, strpos($where, '/', 1));
 
         // Subversion supports patchset diffs natively.
-        $allDiffsLink = Horde::link(Chora::url('diff', $topDir, array('r1' => $id - 1, 'r2' => $id, 'ty' => 'u')),
-                                    _("Diff All Files")) . _("Diff All Files") . '</a>';
+        $patchset_link = Horde::link(Chora::url('diff', $topDir, array('r1' => $id - 1, 'r2' => $id, 't' => 'unified'))) .
+            $id . '</a>';
     } else {
         // Not supported in any other VC systems yet.
-        $allDiffsLink = '';
+        $patchset_link = $id;
     }
 
     $files = array();
@@ -61,19 +67,19 @@ foreach ($patchsets as $id => $patchset) {
     foreach ($patchset['members'] as $member) {
         $file = array();
         $mywhere = is_a($VC, 'VC_svn') ? $member['file'] : $dir . '/' . $member['file'];
-        $file['file'] = Horde::link(Chora::url('patchsets', $mywhere), $member['file']) . $member['file'] . '</a>';
+        $file['file'] = Horde::link(Chora::url('patchsets', $mywhere)) . htmlspecialchars($member['file']) . '</a>';
         if ($member['from'] == 'INITIAL') {
-            $file['from'] = '<i>' . _("New File") . '</i>';
+            $file['from'] = '<ins>' . _("New File") . '</ins>';
             $file['diff'] = '';
         } else {
-            $file['from'] = Horde::link(Chora::url('co', $mywhere, array('r' => $member['from'])), $member['from']) . $member['from'] . '</a>';
-            $file['diff'] = Horde::link(Chora::url('diff', $mywhere, array('r1' => $member['from'], 'r2' => $member['to'], 'ty' => 'u')), _("Diff")) . '(' . _("Diff") . ')';
+            $file['from'] = Horde::link(Chora::url('co', $mywhere, array('r' => $member['from']))) . htmlspecialchars($member['from']) . '</a>';
+            $file['diff'] = Horde::link(Chora::url('diff', $mywhere, array('r1' => $member['from'], 'r2' => $member['to'], 't' => 'unified'))) . ' ' . Horde::img('diff.png', _("Diff")) . '</a>';
         }
         if (substr($member['to'], -6) == '(DEAD)') {
-            $file['to'] = '<i>' . _("Deleted") . '</i>';
+            $file['to'] = '<del>' . _("Deleted") . '</del>';
             $file['diff'] = '';
         } else {
-            $file['to'] = Horde::link(Chora::url('co', $mywhere, array('r' => $member['to'])), $member['to']) . $member['to'] . '</a>';
+            $file['to'] = Horde::link(Chora::url('co', $mywhere, array('r' => $member['to']))) . htmlspecialchars($member['to']) . '</a>';
         }
 
         $files[] = $file;
@@ -83,4 +89,5 @@ foreach ($patchsets as $id => $patchset) {
     require CHORA_TEMPLATES . '/patchsets/ps.inc';
 }
 
+require CHORA_TEMPLATES . '/patchsets/footer.inc';
 require $registry->get('templates', 'horde') . '/common-footer.inc';
